import { useState } from './useState';

interface Session {
    token: string;
    keepLogin: boolean;
}

interface useSession {
    getToken: () => string;
    setToken: (data: Session) => void;
    destroy: () => void;
    isLoggedIn: () => boolean;
}

export function useSession(): useSession {
    function getToken(): string {
        const localToken = localStorage.getItem('token');
        const sessionToken = sessionStorage.getItem('token');

        return localToken || sessionToken || '';
    }

    function setToken(data: Session): void {
        if (data.keepLogin) {
            localStorage.setItem('token', data.token);
        } else {
            sessionStorage.setItem('token', data.token);
        }
    }

    function destroy(): void {
        localStorage.removeItem('token');
        sessionStorage.getItem('token');

        const { setUser } = useState();

        setUser({
            id: 0,
            username: '',
            nickname: '',
        });
    }

    function isLoggedIn() {
        const localToken = localStorage.getItem('token');
        const sessionToken = sessionStorage.getItem('token');

        return !!(localToken || sessionToken);
    }

    return {
        getToken,
        setToken,
        destroy,
        isLoggedIn,
    };
}
