import { jest, describe, expect, it } from '@jest/globals';
import { mount } from '@vue/test-utils';
import { installQuasarPlugin } from '@quasar/quasar-app-extension-testing-unit-jest';
import { i18n } from 'src/boot/i18n';
import { Notify } from 'quasar';
import axios from 'axios';
import Login from '../Login.vue';

// Specify here Quasar config you'll need to test your component
installQuasarPlugin({
    plugins: {
        Notify
    }
});
const routerPushMock = jest.fn();

jest.mock('vue-router', () => ({
    useRouter: () => ({
        push: routerPushMock,
    }),
}));


describe('Login', () => {
    it('should successfully set the token into session', async () => {
        const wrapper = mount(Login, {
            global: {
                plugins: [i18n]
            }
        });
        const { vm } = wrapper;

        jest.spyOn(axios, 'post').mockResolvedValue({ data: { token: 'token' } });
        jest.spyOn(vm.quasar, 'notify')

        expect(vm.session.getToken()).toEqual('');

        await vm.onSubmit();

        expect(vm.session.getToken()).toEqual('token');
        expect(vm.quasar.notify).toHaveBeenCalledWith(expect.objectContaining(
            { 'type': 'positive' }
        ));
        vm.session.destroy();
    });

    it('should not set the token into session if any error occurred', async () => {
        const wrapper = mount(Login, {
            global: {
                plugins: [i18n]
            }
        });
        const { vm } = wrapper;

        jest.spyOn(axios, 'post').mockRejectedValue(new Error('error'));
        jest.spyOn(vm.quasar, 'notify')

        expect(vm.session.getToken()).toEqual('');

        await vm.onSubmit();

        expect(vm.quasar.notify).toHaveBeenCalledWith(expect.objectContaining(
            { 'type': 'negative' }
        ));
    });
});
