import { route } from 'quasar/wrappers';
import { createMemoryHistory, createRouter, createWebHashHistory, createWebHistory } from 'vue-router';
import routes from './routes';
import { i18n } from 'src/boot/i18n';
import { useSession } from 'src/composables/useSession';
const session = useSession();
/*
 * If not building with SSR mode, you can
 * directly export the Router instantiation;
 *
 * The function below can be async too; either use
 * async/await or return a Promise which resolves
 * with the Router instance.
 */

export default route(function (/* { store, ssrContext } */) {
    const createHistory = process.env.SERVER
        ? createMemoryHistory
        : process.env.VUE_ROUTER_MODE === 'history'
        ? createWebHistory
        : createWebHashHistory;

    const Router = createRouter({
        scrollBehavior: () => ({ left: 0, top: 0 }),
        routes,

        // Leave this as is and make changes in quasar.conf.js instead!
        // quasar.conf.js -> build -> vueRouterMode
        // quasar.conf.js -> build -> publicPath
        history: createHistory(process.env.MODE === 'ssr' ? void 0 : process.env.VUE_ROUTER_BASE),
    });

    Router.beforeEach((to, from, next) => {
        const { isLoggedIn } = session;

        if (!isLoggedIn && to.name !== 'Login') {
            next({ path: '/login', query: { redirect: to.fullPath } });
        } else {
            next();
        }
    });

    Router.afterEach((to) => {
        interface Meta {
            title?: string;
        }

        const { t } = i18n.global;
        let title = '';

        const parent = to.matched[1];
        if (parent) {
            const parentMeta: Meta = parent.meta;
            if (parentMeta && parentMeta.title) {
                title += t(`pages.${parentMeta.title}`);
            }
        }
        //const childTitle: string = childMeta.title;

        const childMeta: Meta = to.meta;
        if (childMeta && childMeta.title) {
            if (title != '') title += ' - ';

            title += t(`pages.${childMeta.title}`);
        }

        document.title = title;
    });

    return Router;
});
